@@ -21,14 +21,14 @@
 #ifndef VARIATIONS_H
 #define VARIATIONS_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 
 class Variations : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
         Variations(TQObject *parent, const char *name, const TQStringList &);
     virtual ~Variations();
