@@ -25,10 +25,10 @@
 #include <tqstyle.h>
 
 #include <kgenericfactory.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <kiconloader.h>
-#include <kactioncollection.h>
+#include <tdeactioncollection.h>
 #include <kstdaction.h>
 
 #include <formeditor/container.h>
@@ -210,7 +210,7 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 #endif
 
 /*
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,1,9)
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,1,9)
 	KexiDataAwareWidgetInfo *wDate = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KDateWidget");
 #else
 	KexiDataAwareWidgetInfo *wDate = new KexiDataAwareWidgetInfo(this, "stdwidgets", TQDATEEDIT_OBJECT_NAME_STRING);
@@ -225,7 +225,7 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 	wDate->setDescription(i18n("A widget to input and display a date"));
 	addClass(wDate);
 
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,1,9)
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,1,9)
 	KexiDataAwareWidgetInfo *wTime = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KTimeWidget");
 #else
 	KexiDataAwareWidgetInfo *wTime = new KexiDataAwareWidgetInfo(this, "stdwidgets", TQTIMEEDIT_OBJECT_NAME_STRING);
@@ -240,7 +240,7 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 	wTime->setDescription(i18n("A widget to input and display a time"));
 	addClass(wTime);
 
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,1,9)
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,1,9)
 	KexiDataAwareWidgetInfo *wDateTime = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KDateTimeWidget");
 #else
 	KexiDataAwareWidgetInfo *wDateTime = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KDateTimeWidget");
@@ -425,8 +425,8 @@ KexiDBFactory::createMenuActions(const TQCString &classname, TQWidget *w, TQPopu
 	{
 		KexiDBImageBox *imageBox = static_cast<KexiDBImageBox*>(w);
 		imageBox->contextMenu()->updateActionsAvailability();
-		KActionCollection *ac = imageBox->contextMenu()->actionCollection();
-		KPopupMenu *subMenu = new KPopupMenu();
+		TDEActionCollection *ac = imageBox->contextMenu()->actionCollection();
+		TDEPopupMenu *subMenu = new TDEPopupMenu();
 //! @todo make these actions undoable/redoable
 		menu->insertItem(i18n("&Image"), subMenu);
 		ac->action("insert")->plug(subMenu);
@@ -445,10 +445,10 @@ KexiDBFactory::createMenuActions(const TQCString &classname, TQWidget *w, TQPopu
 }
 
 void
-KexiDBFactory::createCustomActions(KActionCollection* col)
+KexiDBFactory::createCustomActions(TDEActionCollection* col)
 {
 	//this will create shared instance action for design mode (special collection is provided)
-	m_assignAction = new KAction( i18n("&Assign Action..."), SmallIconSet("form_action"),
+	m_assignAction = new TDEAction( i18n("&Assign Action..."), SmallIconSet("form_action"),
 		0, 0, 0, col, "widget_assign_action");
 }
 
