@@ -36,7 +36,7 @@
 
 class TQObject;
 class TQScrollBar;
-class KPopupMenu;
+class TDEPopupMenu;
 class KexiTableItem;
 class KexiTableViewData;
 class KexiRecordMarker;
@@ -419,7 +419,7 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
 		virtual void dataSet( KexiTableViewData *data ) = 0;
 
 		/*! \return a pointer to context menu. This can be used to plug some actions there. */
-		KPopupMenu* contextMenu() const { return m_popupMenu; }
+		TDEPopupMenu* contextMenu() const { return m_popupMenu; }
 
 		/*! \return true if the context menu is enabled (visible) for the view.
 		  True by default. */
@@ -818,7 +818,7 @@ class KEXIDATATABLE_EXPORT KexiDataAwareObjectInterface
 		int m_dragIndicatorLine;
 
 		/*! Context menu widget. */
-		KPopupMenu *m_popupMenu;
+		TDEPopupMenu *m_popupMenu;
 
 		bool m_contextMenuEnabled : 1;
 
