@@ -19,7 +19,7 @@
 #ifndef _KIVIO_PROTECTION_PANEL_H
 #define _KIVIO_PROTECTION_PANEL_H
 
-class KAction;
+class TDEAction;
 class KivioView;
 class KivioLayer;
 
@@ -28,7 +28,7 @@ class KivioLayer;
 class KivioProtectionPanel : public KivioProtectionPanelBase
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     KivioProtectionPanel( KivioView *view, TQWidget *parent=0, const char *name=0 );
