@@ -18,13 +18,13 @@
  * Boston, MA 02110-1301, USA.
 */
 
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <KoUnitWidgets.h>
 #include <knuminput.h>
 #include <knumvalidator.h>
-#include <kfontdialog.h>
+#include <tdefontdialog.h>
 #include <kdebug.h>
 
 #include <tqcheckbox.h>
@@ -54,19 +54,19 @@
 #include <KoVariable.h>
 #include <kformulaconfigpage.h>
 
-#include <kspell2/configwidget.h>
-#include <kspell2/settings.h>
-#include <kspell2/broker.h>
+#include <tdespell2/configwidget.h>
+#include <tdespell2/settings.h>
+#include <tdespell2/broker.h>
 using namespace KSpell2;
 
 #include <float.h>
-#include <kmessagebox.h>
-#include <klistview.h>
+#include <tdemessagebox.h>
+#include <tdelistview.h>
 #include <kstandarddirs.h>
-#include <kglobalsettings.h>
-#include <kglobal.h>
+#include <tdeglobalsettings.h>
+#include <tdeglobal.h>
 #include <kurlrequesterdlg.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <tqtabwidget.h>
 #include <keditlistbox.h>
 #include <KoGlobal.h>
@@ -74,8 +74,8 @@ using namespace KSpell2;
 // little helper stolen from kmail
 // (Note: KDialogBase should have version of the methods that take a TQString for the icon name)
 static inline TQPixmap loadIcon( const char * name ) {
-  return KGlobal::instance()->iconLoader()
-    ->loadIcon( TQString::fromLatin1(name), KIcon::NoGroup, KIcon::SizeMedium );
+  return TDEGlobal::instance()->iconLoader()
+    ->loadIcon( TQString::fromLatin1(name), TDEIcon::NoGroup, TDEIcon::SizeMedium );
 }
 
 KWConfig::KWConfig( KWView* parent )
@@ -89,12 +89,12 @@ KWConfig::KWConfig( KWView* parent )
   m_interfacePage=new ConfigureInterfacePage(parent, page2);
 
   TQVBox *page4 = addVBoxPage( i18n("Document"), i18n("Document Settings"),
-                              loadIcon("kword_kwd") );
+                              loadIcon("x-office-document") );
 
   m_defaultDocPage=new ConfigureDefaultDocPage(parent, page4);
 
   TQVBox *page = addVBoxPage( i18n("Spelling"), i18n("Spell Checker Behavior"),
-                        loadIcon("spellcheck") );
+                        loadIcon("tools-check-spelling") );
   m_spellPage = new ConfigureSpellPage(parent, page);
 
   TQVBox *page5 = addVBoxPage( i18n("Formula"), i18n("Formula Defaults"),
@@ -136,7 +136,7 @@ void KWConfig::unitChanged( int u )
 
 void KWConfig::openPage(int flags)
 {
-    if(flags & KW_KSPELL)
+    if(flags & KW_TDESPELL)
         showPage( 2 );
     else if(flags & KP_INTERFACE)
         showPage(0 );
@@ -296,7 +296,7 @@ ConfigureInterfacePage::ConfigureInterfacePage( KWView *view, TQVBox *box, char
     pgUpDownMovesCaret->setChecked(oldPgUpDownMovesCaret);
     TQWhatsThis::add( pgUpDownMovesCaret, i18n(
                          "If this option is enabled, the PageUp and PageDown keys "
-                         "move the text caret, as in other KDE applications. "
+                         "move the text caret, as in other TDE applications. "
                          "If it is disabled, they move the scrollbars, as in most other word processors." ) );
 
     TQHBox* hbRecent = new TQHBox( gbInterfaceGroup );
@@ -911,14 +911,14 @@ void ConfigureDefaultDocPage::slotDefault()
    m_tabStopWidth->setValue( MM_TO_POINT(15) );
    m_createBackupFile->setChecked( true );
 //    m_directInsertCursor->setChecked( false );
-   m_globalLanguage->setCurrentText( KoGlobal::languageFromTag( KGlobal::locale()->language() ) );
+   m_globalLanguage->setCurrentText( KoGlobal::languageFromTag( TDEGlobal::locale()->language() ) );
    m_autoHyphenation->setChecked( false );
 }
 
 void ConfigureDefaultDocPage::selectNewDefaultFont() {
     TQStringList list;
-    KFontChooser::getFontList(list, KFontChooser::SmoothScalableFonts);
-    KFontDialog dlg( (TQWidget *)this->parent(), "Font Selector", false, true, list, true );
+    TDEFontChooser::getFontList(list, TDEFontChooser::SmoothScalableFonts);
+    TDEFontDialog dlg( (TQWidget *)this->parent(), "Font Selector", false, true, list, true );
     dlg.setFont(*font);
     int result = dlg.exec();
     if (KDialog::Accepted == result) {
@@ -949,7 +949,7 @@ ConfigurePathPage::ConfigurePathPage( KWView *view, TQVBox *box, char *name )
     gbPathGroup->setMargin( KDialog::marginHint() );
     gbPathGroup->setInsideSpacing( KDialog::spacingHint() );
 
-    m_pPathView = new KListView( gbPathGroup );
+    m_pPathView = new TDEListView( gbPathGroup );
     m_pPathView->setResizeMode(TQListView::NoColumn);
     m_pPathView->addColumn( i18n( "Type" ) );
     m_pPathView->addColumn( i18n( "Path" ), 400 ); // not too big by default
